pub enum PathOperation {
Read,
ReadWrite,
CreateTable,
}Expand description
The kind of access requested for a storage path.
Variants
Read
Read-only access.
ReadWrite
Read and write access.
CreateTable
Access for creating a new table at the path.